DSWebSocketProviderMetadata class
Metadata for registered WebSocket providers.
Constructors
Properties
-
additionalMetadata
→ Map<
String, dynamic> ? -
Additional provider-specific metadata.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- protocol → String?
-
Optional protocol.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Provider type (e.g., socket_io).
final
- vendor → String?
-
Optional vendor name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited