DSWebSocketProvider class abstract

WebSocket provider interface for DartStream. Defines the standard interface for all WebSocket providers.

Constructors

DSWebSocketProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String url, {Map<String, dynamic>? headers, Map<String, dynamic>? options}) Future<void>
Connect to a WebSocket endpoint.
disconnect() Future<void>
Disconnect the provider.
dispose() Future<void>
Dispose of the provider and release resources.
emit(String event, dynamic data) → void
Emit an event with optional data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, void handler(dynamic data)) → void
Register an event listener.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited